Update of /cvsroot/alsa/alsa-kernel/include
In directory sc8-pr-cvs1:/tmp/cvs-serv28208/include
Modified Files:
ac97_codec.h
Log Message:
- added spdif field to struct ac97_pcm.
- snd_ac97_set_rate() accepts AC97_SPDIF.
- allow fixed rate mic capture.
- optimized the loop in snd_ac97_pcm_open.
Index: ac97_codec.h
===================================================================
RCS file: /cvsroot/alsa/alsa-kernel/include/ac97_codec.h,v
retrieving revision 1.37
retrieving revision 1.38
diff -u -r1.37 -r1.38
--- ac97_codec.h 20 Nov 2003 15:59:32 -0000 1.37
+++ ac97_codec.h 3 Dec 2003 13:39:06 -0000 1.38
@@ -345,7 +345,8 @@
ac97_bus_t *bus;
unsigned int stream: 1, /* stream type: 1 = capture */
exclusive: 1, /* exclusive mode, don't override with
other pcms */
- copy_flag: 1; /* lowlevel driver must fill all entries */
+ copy_flag: 1, /* lowlevel driver must fill all entries */
+ spdif: 1; /* spdif pcm */
unsigned short aslots; /* active slots */
unsigned int rates; /* available rates */
struct {
-------------------------------------------------------
This SF.net email is sponsored by: SF.net Giveback Program.
Does SourceForge.net help you be more productive? Does it
help you create better code? SHARE THE LOVE, and help us help
YOU! Click Here: http://sourceforge.net/donate/
_______________________________________________
Alsa-cvslog mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/alsa-cvslog